'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (_ref) {
  var t = _ref.types;

  return {
    visitor: {
      ImportDeclaration: function ImportDeclaration(path, file) {
        var _path$node = path.node;
        var specifiers = _path$node.specifiers;
        var source = _path$node.source;

        if (!t.isStringLiteral(source) || !/^files:/.test(source.value)) {
          return;
        }

        assertImportDefaultSpecifier(path, specifiers);

        var fromDir = (0, _path.dirname)(file.file.opts.filename);
        var matches = _glob2.default.sync(getPattern(path, source), {
          // Search relative to the source file, assuming that location is
          // derived correctly.
          cwd: fromDir,
          strict: true
        });

        var prefix = (0, _commonPathPrefix2.default)(matches);
        var details = (0, _create2.default)(null);
        var files = [];
        var _iteratorNormalCompletion2 = true;
        var _didIteratorError2 = false;
        var _iteratorError2 = undefined;

        try {
          for (var _iterator2 = (0, _getIterator3.default)(matches), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
            var filepath = _step2.value;

            var src = (0, _path.resolve)(fromDir, filepath);
            var mimeType = _mimeTypes2.default.lookup(src) || 'application/octet-stream';
            var contentType = _mimeTypes2.default.contentType(mimeType);

            var contents = (0, _fs.readFileSync)(src);
            var contentLength = contents.length;
            var tag = (0, _md5Hex2.default)(contents);

            var relpath = filepath.slice(prefix.length);
            files.push(relpath);
            details[relpath] = {
              contentLength: contentLength,
              contentType: contentType,
              mimeType: mimeType,
              src: src,
              tag: tag
            };
          }
        } catch (err) {
          _didIteratorError2 = true;
          _iteratorError2 = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion2 && _iterator2.return) {
              _iterator2.return();
            }
          } finally {
            if (_didIteratorError2) {
              throw _iteratorError2;
            }
          }
        }

        var makeDetail = function makeDetail(detail) {
          return t.objectExpression([t.objectProperty(t.identifier('contentLength'), t.numericLiteral(detail.contentLength)), t.objectProperty(t.identifier('contentType'), t.stringLiteral(detail.contentType)), t.objectProperty(t.identifier('mimeType'), t.stringLiteral(detail.mimeType)), t.objectProperty(t.identifier('src'), t.stringLiteral(detail.src)), t.objectProperty(t.identifier('tag'), t.stringLiteral(detail.tag))]);
        };

        var _specifiers = (0, _slicedToArray3.default)(specifiers, 1);

        var localName = _specifiers[0].local.name;

        var output = t.variableDeclaration('const', [t.variableDeclarator(t.identifier(localName), t.objectExpression(files.map(function (relpath) {
          return t.objectProperty(t.stringLiteral(relpath), makeDetail(details[relpath]));
        })))]);
        var freezeOutput = t.expressionStatement(t.callExpression(t.memberExpression(t.identifier('Object'), t.identifier('freeze')), [t.identifier(localName)]));

        path.replaceWithMultiple([output, freezeOutput]);
      }
    }
  };
};

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _create = require('babel-runtime/core-js/object/create');

var _create2 = _interopRequireDefault(_create);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _fs = require('fs');

var _path = require('path');

var _commonPathPrefix = require('common-path-prefix');

var _commonPathPrefix2 = _interopRequireDefault(_commonPathPrefix);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _md5Hex = require('md5-hex');

var _md5Hex2 = _interopRequireDefault(_md5Hex);

var _mimeTypes = require('mime-types');

var _mimeTypes2 = _interopRequireDefault(_mimeTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function assertImportDefaultSpecifier(path, specifiers) {
  var hasError = specifiers.length === 0;
  if (!hasError) {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = (0, _getIterator3.default)(specifiers), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var type = _step.value.type;

        if (type !== 'ImportDefaultSpecifier') {
          hasError = true;
          break;
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  }

  if (hasError) {
    throw path.buildCodeFrameError('Can only import the default member from a files: pattern');
  }
}

function getPattern(path, source) {
  var pattern = source.value.replace(/^files:/, '').trim();
  if (!pattern) {
    throw path.buildCodeFrameError('Missing glob pattern \'' + source.value + '\'');
  }
  if (/^\//.test(pattern)) {
    throw path.buildCodeFrameError('Glob pattern must be relative, was \'' + pattern + '\'');
  }
  return pattern;
}
//# sourceMappingURL=index.js.map